const chai = require('chai');

const chaiHttp = require('chai-http');

const assert = chai.assert;

const expect = chai.expect;

const should = chai.should(); // actually call the function

const server = require('../libs/app');

chai.use(chaiHttp);

describe('request enrollments', () => {
    it('should list enrollments', (done) => {
        chai.request(server)
            .get('/v1/enrollment')
            .end((err, res) => {
                res.should.have.status(200);
                res.should.be.json;
                res.body.should.have.property('result');
                res.body.result.should.be.a('array');
                res.body.result[0].should.have.property('name');
                res.body.result[0].should.have.property('total');
                done();
            });
    });
});

describe('request regions', () => {
    it('should list all regions', (done) => {
        chai.request(server)
            .get('/v1/region')
            .end((err, res) => {
                res.should.have.status(200);
                res.should.be.json;
                res.body.should.have.property('result');
                res.body.result.should.be.a('array');
                res.body.result[0].should.have.property('pk_regiao_id');
                res.body.result[0].should.have.property('nome');
                done();
            });
    });

    it('should list region by id', (done) => {
        chai.request(server)
            .get('/v1/region/1')
            .end((err, res) => {
                res.should.have.status(200);
                res.should.be.json;
                res.body.should.have.property('result');
                res.body.result.should.be.a('array');
                res.body.result.should.have.length(1);
                res.body.result[0].should.have.property('pk_regiao_id');
                res.body.result[0].should.have.property('nome');
                done();
            });
    });
});

describe('request states', () => {
    it('should list all states', (done) => {
        chai.request(server)
            .get('/v1/state')
            .end((err, res) => {
                res.should.have.status(200);
                res.should.be.json;
                res.body.should.have.property('result');
                res.body.result.should.be.a('array');
                res.body.result[0].should.have.property('pk_estado_id');
                res.body.result[0].should.have.property('fk_regiao_id');
                res.body.result[0].should.have.property('nome');
                done();
            });
    });

    it('should list a state by id', (done) => {
        chai.request(server)
            .get('/v1/state/11')
            .end((err, res) => {
                res.should.have.status(200);
                res.should.be.json;
                res.body.should.have.property('result');
                res.body.result.should.be.a('array');
                res.body.result.should.have.length(1);
                res.body.result[0].should.have.property('pk_estado_id');
                res.body.result[0].should.have.property('fk_regiao_id');
                res.body.result[0].should.have.property('nome');
                done();
            });
    });

    it('should list states by region id', (done) => {
        chai.request(server)
            .get('/v1/state/region/1')
            .end((err, res) => {
                res.should.have.status(200);
                res.should.be.json;
                res.body.should.have.property('result');
                res.body.result.should.be.a('array');
                res.body.result[0].should.have.property('pk_estado_id');
                res.body.result[0].should.have.property('fk_regiao_id');
                res.body.result[0].should.have.property('nome');
                done();
            });
    });
});

describe('request cities', () => {
    it('should list all cities', (done) => {
        chai.request(server)
            .get('/v1/city')
            .end((err, res) => {
                res.should.have.status(200);
                res.should.be.json;
                res.body.should.have.property('result');
                res.body.result.should.be.a('array');
                res.body.result[0].should.have.property('pk_municipio_id');
                res.body.result[0].should.have.property('fk_estado_id');
                res.body.result[0].should.have.property('nome');
                res.body.result[0].should.have.property('codigo_ibge');
                done();
            });
    });

    it('should list a city by id', (done) => {
        chai.request(server)
            .get('/v1/city/1')
            .end((err, res) => {
                res.should.have.status(200);
                res.should.be.json;
                res.body.should.have.property('result');
                res.body.result.should.be.a('array');
                res.body.result[0].should.have.property('pk_municipio_id');
                res.body.result[0].should.have.property('fk_estado_id');
                res.body.result[0].should.have.property('nome');
                res.body.result[0].should.have.property('codigo_ibge');
                done();
            });
    });

    it('should list a city by codigo_ibge', (done) => {
        chai.request(server)
            .get('/v1/city/ibge/1200013')
            .end((err, res) => {
                res.should.have.status(200);
                res.should.be.json;
                res.body.should.have.property('result');
                res.body.result.should.be.a('array');
                res.body.result[0].should.have.property('pk_municipio_id');
                res.body.result[0].should.have.property('fk_estado_id');
                res.body.result[0].should.have.property('nome');
                res.body.result[0].should.have.property('codigo_ibge');
                done();
            });
    });
});
